==> orgmaker-3-3.0.5.tar.gz: orgmaker-3-3.0.5/source/WinTimer.cpp <==
//Module   : WinTimer.cpp
//include  : mmsystem.h
//Import   : WinMM.lib
//
//Contents : u}`fBA^C}[̎gp@v
//

#include <windows.h>  //Win32n API's
#include <windowsx.h> //mmsystem.h
#include "DefOrg.h"
#include "OrgData.h"

//G[`FbN}N
//#define MMInspect(ret)  if((ret) != TIMERR_NOERROR) return FALSE;

/**/
//vg^Cv錾
/**/

BOOL InitMMTimer();
BOOL StartTimer(DWORD dwTimer);
VOID CALLBACK TimerProc(UINT uTID,UINT uMsg,DWORD dwUser,DWORD dwParam1,DWORD dwParam2);
BOOL QuitMMTimer();

/**/
//O[oϐ
/**/
static UINT ExactTime   = 13;//ŏx
static UINT TimerID     = NULL;

/**/
//^C}[xݒ肷B
//̊֐̓AvP[VɈxĂяoB
/**/
BOOL InitMMTimer()
{
	TIMECAPS tc;
	MMRESULT ret;

	//^C}[̐x擾
	ret = timeGetDevCaps(&tc,sizeof(TIMECAPS));
	if(ret != TIMERR_NOERROR) return FALSE;
	if(ExactTime < tc.wPeriodMin)ExactTime = tc.wPeriodMin;
	//̐xŏ
	ret = timeBeginPeriod(ExactTime);
	if(ret != TIMERR_NOERROR) return FALSE;
	return TRUE;
}

/**/
//^C}[NB
//dwTimer   ݒ肷^C}[Ԋu
/**/
BOOL StartTimer(DWORD dwTimer)
{
	MMRESULT ret = NULL;
	ExactTime = dwTimer;
	//^C}[𐶐
	TimerID = timeSetEvent
	(
		dwTimer,       //^C}[
		10,             //eł^C}[x
		(LPTIMECALLBACK)TimerProc, //R[obNvV[W
		NULL,          //[U[R[obN֐dwUserɑl
		TIME_PERIODIC //^C}[ԖɃCxg𔭐
	);
	if(ret != TIMERR_NOERROR) return FALSE;
	return TRUE;
}
/**/
//^C}[̃R[obN֐
/**/
VOID CALLBACK TimerProc(UINT uTID,UINT uMsg,DWORD dwUser,DWORD dwParam1,DWORD dwParam2)
{
	DWORD dwNowTime;
	dwNowTime = timeGetTime();
	//===================================================================================
	//Ƀ[U[`̃\[XB
	//{IɊ֐Ăяoŏ͑̊֐łׂ낤B
	//===================================================================================
	org_data.PlayData();
}

/**/
//^C}[\[XJB
//AvP[VIɈxĂяoB
/**/
BOOL QuitMMTimer()
{
	MMRESULT ret;

	if(TimerID != TIMERR_NOERROR)
	{
		//^C}[gpȂI
		ret = timeKillEvent(TimerID);
		if((ret) != TIMERR_NOERROR) return FALSE;
	}
	//^C}[\[XJ
	ret = timeEndPeriod(ExactTime);
	if((ret) != TIMERR_NOERROR) return FALSE;
	return TRUE;
}

==> orgmaker-3-3.0.9.tar.gz: orgmaker-3-3.0.9/source/WinTimer.cpp <==
//Module   : WinTimer.cpp
//include  : mmsystem.h
//Import   : WinMM.lib
//
//Contents : u}`fBA^C}[̎gp@v
//

#include <windows.h>  //Win32n API's
#include "DefOrg.h"
#include "OrgData.h"
#include "Sound.h"

//G[`FbN}N
//#define MMInspect(ret)  if((ret) != TIMERR_NOERROR) return FALSE;

/**/
//vg^Cv錾
/**/

BOOL InitMMTimer();
BOOL StartTimer(DWORD dwTimer);
//VOID CALLBACK TimerProc(UINT uTID,UINT uMsg,DWORD dwUser,DWORD dwParam1,DWORD dwParam2);
BOOL QuitMMTimer();

/**/
//O[oϐ
/**/
static UINT ExactTime   = 13;//ŏx
static UINT TimerID     = NULL;

/**/
//^C}[xݒ肷B
//̊֐̓AvP[VɈxĂяoB
/**/
BOOL InitMMTimer()
{
	/*TIMECAPS tc;
	MMRESULT ret;

	//^C}[̐x擾
	ret = timeGetDevCaps(&tc,sizeof(TIMECAPS));
	if(ret != TIMERR_NOERROR) return FALSE;
	if(ExactTime < tc.wPeriodMin)ExactTime = tc.wPeriodMin;
	//̐xŏ
	ret = timeBeginPeriod(ExactTime);
	if(ret != TIMERR_NOERROR) return FALSE;
	return TRUE;*/

	return TRUE;
}

/**/
//^C}[NB
//dwTimer   ݒ肷^C}[Ԋu
/**/
BOOL StartTimer(DWORD dwTimer)
{
	/*MMRESULT ret = NULL;
	ExactTime = dwTimer;
	//^C}[𐶐
	TimerID = timeSetEvent
	(
		dwTimer,       //^C}[
		1,             //eł^C}[x
		(LPTIMECALLBACK)TimerProc, //R[obNvV[W
		NULL,          //[U[R[obN֐dwUserɑl
		TIME_PERIODIC //^C}[ԖɃCxg𔭐
	);
	if(ret != TIMERR_NOERROR) return FALSE;
	return TRUE;*/

	S_SetOrganyaTimer(dwTimer);
	return TRUE;
}
/**/
//^C}[̃R[obN֐
/**/
/*VOID CALLBACK TimerProc(UINT uTID,UINT uMsg,DWORD dwUser,DWORD dwParam1,DWORD dwParam2)
{
	DWORD dwNowTime;
	dwNowTime = timeGetTime();
	//===================================================================================
	//Ƀ[U[`̃\[XB
	//{IɊ֐Ăяoŏ͑̊֐łׂ낤B
	//===================================================================================
	org_data.PlayData();
}*/

/**/
//^C}[\[XJB
//AvP[VIɈxĂяoB
/**/
BOOL QuitMMTimer()
{
	/*MMRESULT ret;

	if(TimerID != TIMERR_NOERROR)
	{
		//^C}[gpȂI
		ret = timeKillEvent(TimerID);
		if((ret) != TIMERR_NOERROR) return FALSE;
	}
	//^C}[\[XJ
	ret = timeEndPeriod(ExactTime);
	if((ret) != TIMERR_NOERROR) return FALSE;
	return TRUE;*/

	S_SetOrganyaTimer(0);
	return TRUE;
}
